﻿using Microsoft.AspNetCore.Mvc;
using ComputerShopContracts.BindingModels;
using ComputerShopContracts.BusinessLogicContracts;
using ComputerShopContracts.SearchModels;
using ComputerShopContracts.ViewModels;
using System.Reflection;

namespace ComputerShopRestApi.Controllers
{
    [Route("api/[controller]/[action]")]
    [ApiController]
    public class ComponentController : Controller
    {
        private readonly ILogger _logger;
        private readonly IComponentLogic _component;
        public ComponentController(ILogger<ComponentController> logger, IComponentLogic component)
        {
            _logger = logger;
            _component = component;
        }
        [HttpGet]
        public List<ComponentViewModel>? GetComponentList(int clientId)
        {
            try
            {
                return _component.ReadList(new ComponentSearchModel
                {
                    ClientId = clientId,
                });
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка получения списка компонентов");
                throw;
            }
        }
        [HttpPost]
        public void CreateComponent(ComponentBindingModel model)
        {
            try
            {
                _component.Create(model);
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка создания компонента");
                throw;
            }
        }
        [HttpPost]
        public void DeleteComponent(ComponentBindingModel model)
        {
            try
            {
                _component.Delete(model);
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка удаления компонента");
                throw;
            }
        }

        [HttpPost]
        public void EditComponent(ComponentBindingModel model)
        {
            try
            {
                _component.Update(model);
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка изменения компонента");
                throw;
            }
        }

        [HttpGet]
        public ComponentViewModel? GetComponent(int componentId)
        {
            try
            {
                return _component.ReadElement(new ComponentSearchModel { Id = componentId });
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка получения компонента по id={Id}", componentId);
                throw;
            }
        }
    }
}
